# -*- coding: UTF-8 -*-
# Copyright (C) 2020 Brandon M. Pace
#
# This file is part of freezehelper
#
# freezehelper is free software: you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# freezehelper is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with freezehelper.
# If not, see <https://www.gnu.org/licenses/>.

"""module for small helper functions"""


import multiprocessing
import os
import sys


frozen = getattr(sys, "frozen", False)
from_source = not frozen


is_linux = sys.platform.startswith("linux")
is_not_linux = not is_linux
is_mac = sys.platform == "darwin"
is_not_mac = not is_mac
is_windows = sys.platform == "win32"
is_not_windows = not is_windows


def get_executable_dir(resolve_links: bool = True) -> str:
    return os.path.dirname(get_executable_path(resolve_links))


def get_executable_path(resolve_links: bool = True) -> str:
    if frozen:
        my_path = sys.executable
    else:
        my_path = sys.argv[0]
    if resolve_links:
        my_path = os.path.realpath(my_path)
    return os.path.abspath(my_path)


def is_child_process() -> bool:
    """Returns True if the current context is not the main process"""
    if is_windows and frozen and (len(sys.argv) >= 2) and (sys.argv[1] == "--multiprocessing-fork"):
        return True  # frozen Windows executable child process
    elif multiprocessing.current_process().name != "MainProcess":
        return True
    else:
        return False


def is_main_process() -> bool:
    """Returns True if the current context is the main process"""
    return not is_child_process()



# -*- coding: UTF-8 -*-
# Copyright (C) 2020 Brandon M. Pace
#
# This file is part of freezehelper
#
# freezehelper is free software: you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# freezehelper is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with freezehelper.
# If not, see <https://www.gnu.org/licenses/>.

"""Package to provide simple check for being frozen (compiled) and other items"""


__author__ = "Brandon M. Pace"
__copyright__ = "Copyright 2020 Brandon M. Pace"
__license__ = "GNU LGPL 3+"
__maintainer__ = "Brandon M. Pace"
__status__ = "Production"
__version__ = "2.0.0"


from .helpers import get_executable_dir, get_executable_path
from .helpers import is_linux, is_mac, is_windows, is_not_linux, is_not_mac, is_not_windows
from .helpers import from_source, frozen, is_child_process, is_main_process

executable_dir = get_executable_dir()
executable_path = get_executable_path()



import setuptools

with open("README.rst", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="freezehelper",
    version="2.0.0",
    author="Brandon M. Pace",
    author_email="brandonmpace@gmail.com",
    description="A Python package to simplify checks for frozen state and executable directory",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    keywords="freeze frozen PyInstaller parent child process executable directory path",
    license="GNU Lesser General Public License v3 or later",
    platforms=['any'],
    python_requires=">=3.6.5",
    url="https://github.com/brandonmpace/freezehelper",
    packages=setuptools.find_packages(),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3"
    ]
)
